==> supper_app-0.0.4.tar.gz: flutter-login/lib/src/login_screen.dart <==
import 'package:flutter/material.dart';
import 'package:supper_app/supper_app.dart';

class LoginProps implements Argument {
  late String? successfully;
  late String? failure;
  @override
  Map<String, dynamic> toMap() {
    return {"successfully": successfully, "failure": failure};
  }

  LoginProps.fromMap(Map<String, dynamic> map) {
    failure = map["failure"];
    successfully = map["successfully"];
  }
}

class LoginScreen extends StatefulWidget {
  LoginProps props;
  final VoidCallback? successfullyCallBack;
  final VoidCallback? failureCallBack;
  LoginScreen(
      {Key? key,
      required this.props,
      this.successfullyCallBack,
      this.failureCallBack})
      : super(key: key);

  @override
  // ignore: library_private_types_in_public_api
  _LoginScreenState createState() =>
      // ignore: no_logic_in_create_state
      _LoginScreenState(props, successfullyCallBack, failureCallBack);
}

class _LoginScreenState extends State<LoginScreen> {
  LoginProps props;
  final VoidCallback? successfullyCallBack;
  final VoidCallback? failureCallBack;
  _LoginScreenState(
      this.props, this.successfullyCallBack, this.failureCallBack);

  @override
  Widget build(BuildContext context) {
    return Container(
      // decoration: const BoxDecoration(
      //   image: DecorationImage(
      //       image: AssetImage('assets/images/login.png'), fit: BoxFit.cover),
      // ),
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: Stack(children: [
          // Container(
          //   padding: const EdgeInsets.only(left: 35, top: 80),
          //   child: const Text(
          //     "Welcome\nBack",
          //     style: TextStyle(color: Colors.white, fontSize: 33),
          //   ),
          // ),
          SingleChildScrollView(
            child: Container(
              padding: EdgeInsets.only(
                  right: 35,
                  left: 35,
                  top: MediaQuery.of(context).size.height * 0.5),
              child: Column(children: [
                TextField(
                  decoration: InputDecoration(
                    fillColor: Colors.grey.shade100,
                    filled: true,
                    hintText: 'Email',
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                    ),
                  ),
                ),
                const SizedBox(
                  height: 30,
                ),
                TextField(
                  obscureText: true,
                  decoration: InputDecoration(
                    fillColor: Colors.grey.shade100,
                    filled: true,
                    hintText: 'Password',
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                    ),
                  ),
                ),
                const SizedBox(
                  height: 40,
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    const Text(
                      'Sign In',
                      style: TextStyle(
                        color: Color(0xff4c505b),
                        fontSize: 27,
                        fontWeight: FontWeight.w700,
                      ),
                    ),
                    CircleAvatar(
                      radius: 30,
                      backgroundColor: const Color(0xff4c505b),
                      child: IconButton(
                        color: Colors.white,
                        onPressed: () {
                          Auth().authenticate(1);
                          if (props.successfully != null) {
                            Navigator.pushNamed(context, props.successfully!);
                          } else if (successfullyCallBack != null) {
                            successfullyCallBack!();
                          } else {
                            Navigator.pop(context);
                          }
                        },
                        icon: const Icon(Icons.arrow_forward),
                      ),
                    ),
                  ],
                ),
                const SizedBox(
                  height: 40,
                ),
                Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      TextButton(
                        onPressed: () {
                          if (props.failure != null) {
                            Navigator.pushNamed(context, props.failure!);
                          } else if (failureCallBack != null) {
                            failureCallBack!();
                          } else {
                            Navigator.pop(context);
                          }
                        },
                        child: const Text(
                          'skip',
                          style: TextStyle(
                            decoration: TextDecoration.underline,
                            fontSize: 18,
                            color: Color(0xff4c505b),
                          ),
                        ),
                      ),
                      // TextButton(
                      //   onPressed: () {},
                      //   child: const Text(
                      //     'Forgot Password',
                      //     style: TextStyle(
                      //       decoration: TextDecoration.underline,
                      //       fontSize: 18,
                      //       color: Color(0xff4c505b),
                      //     ),
                      //   ),
                      // ),
                    ]),
              ]),
            ),
          ),
        ]),
      ),
    );
  }
}

==> supper_app-0.0.6.tar.gz: flutter-login/lib/src/login_screen.dart <==
import 'package:flutter/material.dart';
import 'package:supper_app/supper_app.dart';

class LoginProps implements Argument {
  late String? successfully;
  late String? failure;
  @override
  Map<String, dynamic> toMap() {
    return {"successfully": successfully, "failure": failure};
  }

  LoginProps.fromMap(Map<String, dynamic> map) {
    failure = map["failure"];
    successfully = map["successfully"];
  }
}

class LoginScreen extends StatefulWidget {
  LoginProps props;
  final VoidCallback? successfullyCallBack;
  final VoidCallback? failureCallBack;
  LoginScreen(
      {Key? key,
      required this.props,
      this.successfullyCallBack,
      this.failureCallBack})
      : super(key: key);

  @override
  // ignore: library_private_types_in_public_api
  _LoginScreenState createState() =>
      // ignore: no_logic_in_create_state
      _LoginScreenState(props, successfullyCallBack, failureCallBack);
}

class _LoginScreenState extends State<LoginScreen> {
  LoginProps props;
  final VoidCallback? successfullyCallBack;
  final VoidCallback? failureCallBack;
  _LoginScreenState(
      this.props, this.successfullyCallBack, this.failureCallBack);

  @override
  Widget build(BuildContext context) {
    return Container(
      // decoration: const BoxDecoration(
      //   image: DecorationImage(
      //       image: AssetImage('assets/images/login.png'), fit: BoxFit.cover),
      // ),
      child: Scaffold(
        backgroundColor: Colors.transparent,
        body: Stack(children: [
          // Container(
          //   padding: const EdgeInsets.only(left: 35, top: 80),
          //   child: const Text(
          //     "Welcome\nBack",
          //     style: TextStyle(color: Colors.white, fontSize: 33),
          //   ),
          // ),
          SingleChildScrollView(
            child: Container(
              padding: EdgeInsets.only(
                  right: 35,
                  left: 35,
                  top: MediaQuery.of(context).size.height * 0.5),
              child: Column(children: [
                TextField(
                  decoration: InputDecoration(
                    fillColor: Colors.grey.shade100,
                    filled: true,
                    hintText: 'Email',
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                    ),
                  ),
                ),
                const SizedBox(
                  height: 30,
                ),
                TextField(
                  obscureText: true,
                  decoration: InputDecoration(
                    fillColor: Colors.grey.shade100,
                    filled: true,
                    hintText: 'Password',
                    border: OutlineInputBorder(
                      borderRadius: BorderRadius.circular(10),
                    ),
                  ),
                ),
                const SizedBox(
                  height: 40,
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: [
                    const Text(
                      'Sign In',
                      style: TextStyle(
                        color: Color(0xff4c505b),
                        fontSize: 27,
                        fontWeight: FontWeight.w700,
                      ),
                    ),
                    CircleAvatar(
                      radius: 30,
                      backgroundColor: const Color(0xff4c505b),
                      child: IconButton(
                        color: Colors.white,
                        onPressed: () {
                          Auth().authenticate(User());
                          if (props.successfully != null) {
                            Navigator.pushNamed(context, props.successfully!);
                          } else if (successfullyCallBack != null) {
                            successfullyCallBack!();
                          } else {
                            Navigator.pop(context);
                          }
                        },
                        icon: const Icon(Icons.arrow_forward),
                      ),
                    ),
                  ],
                ),
                const SizedBox(
                  height: 40,
                ),
                Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      TextButton(
                        onPressed: () {
                          if (props.failure != null) {
                            Navigator.pushNamed(context, props.failure!);
                          } else if (failureCallBack != null) {
                            failureCallBack!();
                          } else {
                            Navigator.pop(context);
                          }
                        },
                        child: const Text(
                          'skip',
                          style: TextStyle(
                            decoration: TextDecoration.underline,
                            fontSize: 18,
                            color: Color(0xff4c505b),
                          ),
                        ),
                      ),
                      // TextButton(
                      //   onPressed: () {},
                      //   child: const Text(
                      //     'Forgot Password',
                      //     style: TextStyle(
                      //       decoration: TextDecoration.underline,
                      //       fontSize: 18,
                      //       color: Color(0xff4c505b),
                      //     ),
                      //   ),
                      // ),
                    ]),
              ]),
            ),
          ),
        ]),
      ),
    );
  }
}
